==> estateplat-common-1.1.0-20161112.024508-218-sources.jar: cn/gtmap/estateplat/model/server/core/BdcZjjzwxx.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * Created with IntelliJ IDEA.
 * User: apple
 * Date: 15-12-15
 * Time: 上午11:36
 * To change this template use File | Settings | File Templates.
 */
@Table(name = "bdc_zjjzwxx")
public class BdcZjjzwxx implements InsertVo,Serializable {
    @Id
    private String zjwid;
    private String xh;
    private String zl;
    private String yt;
    private Double jzmj;
    private String jzjg;
    private String zrzh;
    private String fjh;
    private String zcs;
    private String szc;
    private String proid;
    private Double jyjg;
  //  private String fwxz;//房屋性质
    private String dw;
    private  Double dymj;
    private  String bdcdyh;
    private  String fwbm;
    private  String dyzt;
    private String jyyy;//解押原因
    private String jyr;//解押人
    private Date jyrq;//解押日期

    public String getZjwid() {
        return zjwid;
    }

    public void setZjwid(String zjwid) {
        this.zjwid = zjwid;
    }

    public String getXh() {
        return xh;
    }

    public void setXh(String xh) {
        this.xh = xh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }



    public String getJzjg() {
        return jzjg;
    }

    public void setJzjg(String jzjg) {
        this.jzjg = jzjg;
    }

    public String getZrzh() {
        return zrzh;
    }

    public void setZrzh(String zrzh) {
        this.zrzh = zrzh;
    }

    public String getFjh() {
        return fjh;
    }

    public void setFjh(String fjh) {
        this.fjh = fjh;
    }

    public String getZcs() {
        return zcs;
    }

    public void setZcs(String zcs) {
        this.zcs = zcs;
    }

    public String getSzc() {
        return szc;
    }

    public void setSzc(String szc) {
        this.szc = szc;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public Double getJyjg() {
        return jyjg;
    }

    public void setJyjg(Double jyjg) {
        this.jyjg = jyjg;
    }

//    public String getFwxz() {
//        return fwxz;
//    }
//
//    public void setFwxz(String fwxz) {
//        this.fwxz = fwxz;
//    }

    public String getDw() {
        return dw;
    }

    public void setDw(String dw) {
        this.dw = dw;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Double getDymj() {
        return dymj;
    }

    public void setDymj(Double dymj) {
        this.dymj = dymj;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getFwbm() {
        return fwbm;
    }

    public void setFwbm(String fwbm) {
        this.fwbm = fwbm;
    }

    public String getDyzt() {
        return dyzt;
    }

    public void setDyzt(String dyzt) {
        this.dyzt = dyzt;
    }

    public String getJyyy() {
        return jyyy;
    }

    public void setJyyy(String jyyy) {
        this.jyyy = jyyy;
    }

    public String getJyr() {
        return jyr;
    }

    public void setJyr(String jyr) {
        this.jyr = jyr;
    }

    public Date getJyrq() {
        return jyrq;
    }

    public void setJyrq(Date jyrq) {
        this.jyrq = jyrq;
    }
}

==> estateplat-common-1.1.0-20161229.095144-237-sources.jar: cn/gtmap/estateplat/model/server/core/BdcZjjzwxx.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * Created with IntelliJ IDEA.
 * User: apple
 * Date: 15-12-15
 * Time: 上午11:36
 * To change this template use File | Settings | File Templates.
 */
@Table(name = "bdc_zjjzwxx")
public class BdcZjjzwxx implements InsertVo,Serializable {
    @Id
    private String zjwid;
    private String xh;
    private String zl;
    private String yt;
    private Double jzmj;
    private String jzjg;
    private String zrzh;
    private String fjh;
    private String zcs;
    private String szc;
    private String proid;
    private Double jyjg;
  //  private String fwxz;//房屋性质
    private String dw;
    private  Double dymj;
    private  String bdcdyh;
    private  String fwbm;
    private  String dyzt;
    private String jyyy;//解押原因
    private String jyr;//解押人
    private Date jyrq;//解押日期
    private  Double ftmj;//分摊面积

    public Double getFtmj() {
        return ftmj;
    }

    public void setFtmj(Double ftmj) {
        this.ftmj = ftmj;
    }

    public String getZjwid() {
        return zjwid;
    }

    public void setZjwid(String zjwid) {
        this.zjwid = zjwid;
    }

    public String getXh() {
        return xh;
    }

    public void setXh(String xh) {
        this.xh = xh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }



    public String getJzjg() {
        return jzjg;
    }

    public void setJzjg(String jzjg) {
        this.jzjg = jzjg;
    }

    public String getZrzh() {
        return zrzh;
    }

    public void setZrzh(String zrzh) {
        this.zrzh = zrzh;
    }

    public String getFjh() {
        return fjh;
    }

    public void setFjh(String fjh) {
        this.fjh = fjh;
    }

    public String getZcs() {
        return zcs;
    }

    public void setZcs(String zcs) {
        this.zcs = zcs;
    }

    public String getSzc() {
        return szc;
    }

    public void setSzc(String szc) {
        this.szc = szc;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public Double getJyjg() {
        return jyjg;
    }

    public void setJyjg(Double jyjg) {
        this.jyjg = jyjg;
    }

//    public String getFwxz() {
//        return fwxz;
//    }
//
//    public void setFwxz(String fwxz) {
//        this.fwxz = fwxz;
//    }

    public String getDw() {
        return dw;
    }

    public void setDw(String dw) {
        this.dw = dw;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Double getDymj() {
        return dymj;
    }

    public void setDymj(Double dymj) {
        this.dymj = dymj;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getFwbm() {
        return fwbm;
    }

    public void setFwbm(String fwbm) {
        this.fwbm = fwbm;
    }

    public String getDyzt() {
        return dyzt;
    }

    public void setDyzt(String dyzt) {
        this.dyzt = dyzt;
    }

    public String getJyyy() {
        return jyyy;
    }

    public void setJyyy(String jyyy) {
        this.jyyy = jyyy;
    }

    public String getJyr() {
        return jyr;
    }

    public void setJyr(String jyr) {
        this.jyr = jyr;
    }

    public Date getJyrq() {
        return jyrq;
    }

    public void setJyrq(Date jyrq) {
        this.jyrq = jyrq;
    }
}
